// This file was automatically generated by bifcl from /usr/obj/ports/zeek-8.1.1/zeek-8.1.1/src/analyzer/protocol/ntlm/types.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_usr_obj_ports_zeek_8_1_1_build_powerpc_src_analyzer_protocol_ntlm_types_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _usr_obj_ports_zeek_8_1_1_build_powerpc_src_analyzer_protocol_ntlm_types_bif
#define _usr_obj_ports_zeek_8_1_1_build_powerpc_src_analyzer_protocol_ntlm_types_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifType::Record::NTLM { extern zeek::IntrusivePtr<zeek::RecordType> Negotiate; }
namespace zeek::BifType::Record::NTLM { extern zeek::IntrusivePtr<zeek::RecordType> Challenge; }
namespace zeek::BifType::Record::NTLM { extern zeek::IntrusivePtr<zeek::RecordType> Authenticate; }
namespace zeek::BifType::Record::NTLM { extern zeek::IntrusivePtr<zeek::RecordType> NegotiateFlags; }
namespace zeek::BifType::Record::NTLM { extern zeek::IntrusivePtr<zeek::RecordType> Version; }
namespace zeek::BifType::Record::NTLM { extern zeek::IntrusivePtr<zeek::RecordType> AVs; }

#endif
